@@ -599,6 +599,15 @@ def resize_widget(widget: tk.Widget, size: int = 10):
         pass
 
 
+def Error(text):
+    try:
+        from colorama import Fore
+    except ImportError:
+        print(text)
+    else:
+        print(Fore.RED+text+Fore.RESET)
+
+
 class DevAccumulatorButton(tk.Button):
     def __init__(self):
         super(DevAccumulatorButton, self).__init__()
@@ -880,6 +889,58 @@ class DevImage(tk.Label):
         super(DevImage, self).__init__(master=master, image=image)
 
 
+class DevNotifyIcon(object):
+    def __init__(self, master: tk.Tk, tip: str = "托盘图标", icon=Icon_Folder):
+        import os.path
+        self._hWnd = GetParent(master.winfo_id())
+        self._icon = icon
+        self._icon_flags = LR_LOADFROMFILE | LR_DEFAULTSIZE
+        self._hinst = GetModuleHandle(None)
+        if os.path.isfile(self._icon):
+            self._hicon = LoadImage(self._hinst,
+                                    self._icon,
+                                    IMAGE_ICON,
+                                    0,
+                                    0,
+                                    self._icon_flags
+                                    )
+        else:
+            Error("我们没有找到图标文件，将使用默认的图标")
+            self._hicon = LoadIcon(0, IDI_APPLICATION)
+        self._notify_id = (self.hWnd,
+                           0,
+                           NIF_ICON | NIF_MESSAGE | NIF_TIP,
+                           WM_USER + 20,
+                           self._hicon,
+                           tip)
+
+    @property
+    def notify_id(self):
+        return self.notify_id
+
+    @notify_id.setter
+    def notify_id(self, nid):
+        self._notify_id = nid
+
+    @property
+    def hWnd(self):
+        return self._hWnd
+
+    @hWnd.setter
+    def hWnd(self, hWnd):
+        self._hWnd = hWnd
+
+    def add(self):
+        Shell_NotifyIcon(NIM_ADD, self._notify_id)
+
+
+    def delete(self):
+        Shell_NotifyIcon(NIM_DELETE, self._notify_id)
+
+    def modify(self):
+        Shell_NotifyIcon(NIM_MODIFY, self._notify_id)
+
+
 class DevMenu(tk.Menubutton):
     def __init__(self, master=None, menu: tk.Menu = None, text: str = "", bg="#fafafa", fg="#000000",
                  active_bg="#3c7bfc", active_fg="#ffffff"):
@@ -1138,6 +1199,7 @@ class DevWindow(tk.Tk):
         设置窗口材质为亚克力，
 
         :param mode: 为主题默认是自动
+        :param mica: 启用mica
         """
         if mica:
             self.mica(mode)
@@ -1365,4 +1427,6 @@ class DevTooltip(DevToplevel):
 
 if __name__ == '__main__':
     Window = DevWindow()
+    NotifyIcon = DevNotifyIcon(Window)
+    NotifyIcon.add()
     Window.mainloop()
