@@ -1,4 +1,4 @@
-from src.tkdev_edit import Editor
+from tkdev_edit import Editor
 
 
 if __name__ == '__main__':
